#!/usr/bin/python
#_*_encoding:utf-8_*_

import requests
import glo

def test_passing():
    res = requests.get(glo.get_value("ep") + "/api/pipeline/list?page_num=1&page_size=10")
    print("\n----------------")
    print(res.json()["msg"])
    assert res.json()["page_info"]["total"] == 7


from setuptools import setup,find_packages

setup(
	name = "TeleAuto",
	version = "0.0.2",
	keywords = [],
	description = "tele's auto",
	long_description = "tele's auto",
	license = "MIT",
	url = "https://github.com/hikkki/py-try",
	author = "yxq",
	author_email = "yunyxq@163.com",
	#packages = find_packages(),
	packages = ['cases'],
	include_package_data = True,
	platforms = "any",
	install_requires = []
)